@@ -5,4 +5,4 @@ import sys
 from afasi.cli import app
 
 if __name__ == '__main__':
-    sys.exit(app(prog_name='foran'))  # pragma: no cover
+    sys.exit(app(prog_name='afasi'))  # pragma: no cover
