@@ -3,7 +3,6 @@
 # pylint: disable=line-too-long
 """Commandline API gateway for afasi."""
 import sys
-from typing import List, Union
 
 import typer
 
@@ -167,11 +166,3 @@ def app_version() -> None:
     Display the afasi version and exit
     """
     callback(True)
-
-
-# pylint: disable=expression-not-assigned
-# @app.command()
-def main(argv: Union[List[str], None] = None) -> int:
-    """Delegate processing to functional module."""
-    argv = sys.argv[1:] if argv is None else argv
-    return af.main(argv)
